<script setup>
import FlexLayout from "@/components/FlexLayout.vue";
import {Expand, ArrowDown, ArrowUp, Avatar, Fold} from "@element-plus/icons-vue";
import userDropdown from "@/views/mainLayout/js/userDropdown";
import slideMenu from "@/views/mainLayout/js/slideMenu";
import usePageMenuStore from "@/store/usePageMenuStore";

const {isCollapse} = slideMenu();
const {isVisible, visibleChange, commandClick} = userDropdown();

const pageMenuStore = usePageMenuStore();
const changeMenuState = ()=>{
	pageMenuStore.changeCollapse(!isCollapse.value);
}
</script>

<template>
	<div class="header-wrapper">
		<div class="header-left-wrapper">
				<span class="menu-state-icon" @click="changeMenuState">
					<el-icon size="20">
						<Fold v-if="!isCollapse" />
						<Expand v-else/>
					</el-icon>
				</span>
			<span class="sys-name">安琪酵母（西藏）益生菌信息采集中心智能实验室</span>
			<span class="sys-version">V1.121</span>
		</div>
		<div class="page-header-right">
			<div class="hdw-avatar">
				<el-dropdown @command="commandClick" @visible-change="visibleChange">
					<div class="hdw-avatar-wrapper">
								<span class="hdw-avatar-icon">
		              <el-icon size="18"><Avatar /></el-icon>
		            </span>
						<span class="hdw-avatar-text">admin</span>
						<el-icon size="16">
							<ArrowUp v-if="isVisible" />
							<ArrowDown v-else />
						</el-icon>
					</div>
					<template #dropdown>
						<el-dropdown-menu>
							<el-dropdown-item command="passwordChange">密码修改</el-dropdown-item>
							<el-dropdown-item command="outSystem">安全退出</el-dropdown-item>
						</el-dropdown-menu>
					</template>
				</el-dropdown>
			</div>
		</div>
	</div>
</template>

<style lang="less" scoped>
.header-wrapper {
	display: flex;
}
.header-left-wrapper {
	flex: 1;
	user-select: none;
	height: 62px;
	align-items: center;
	padding-right: 150px;
	background-image: url("@/assets/images/page-header-left-bg.png");
	background-repeat: no-repeat;
	background-size: 150% 100%;
	color: @font-color-high-light;
	overflow: hidden;
	white-space: nowrap;
	text-overflow: ellipsis;
	span {
		font-size: 32px;
		font-weight: bold;
		letter-spacing: 0.2rem;
		&.menu-state-icon {
			display: inline-block;
			text-align: center;
			padding: 4px 8px;
			cursor: pointer;
		}
		&.sys-name {
			overflow: hidden;
			white-space: nowrap;
			text-overflow: ellipsis;
		}
		&.sys-version {
			padding-top: 8px;
			font-size: 16px;
			vertical-align: middle;
		}
	}
}
.page-header-right {
	.hdw-avatar {
		padding: 8px 16px;
	}
	.hdw-avatar-text {
		color: @font-color-primary;
		margin-left: 4px;
		margin-right: 4px;
		vertical-align: center;
	}
}
.hdw-avatar-wrapper {
	cursor: pointer;
	color: @font-color-primary;
	white-space: nowrap;
}
.hdw-avatar-wrapper:focus-visible {
	outline: none;
}

.hdw-avatar-icon {
	display: inline-flex;
	width: 38px;
	height: 38px;
	border-radius: 50%;
	justify-content: center;
	background-color: #4ba1fa;
	align-items: center;
	color: #032c8f;
}
</style>
